summaryrefslogtreecommitdiffstats
path: root/libk3b/tools/k3bactivepipe.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
commitd8cc8bdfa7fa624a526d5aa1626974e1444cb799 (patch)
treef295f1c545b319963d5357af79fe08991d8141d9 /libk3b/tools/k3bactivepipe.h
parent2a39a080579fb52a2599c02b2939795385b89093 (diff)
downloadk3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.tar.gz
k3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.zip
TQt4 port k3b
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k3b@1233803 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk3b/tools/k3bactivepipe.h')
-rw-r--r--libk3b/tools/k3bactivepipe.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/libk3b/tools/k3bactivepipe.h b/libk3b/tools/k3bactivepipe.h
index 367646d..fc2a32d 100644
--- a/libk3b/tools/k3bactivepipe.h
+++ b/libk3b/tools/k3bactivepipe.h
@@ -16,12 +16,12 @@
#ifndef _K3B_ACTIVE_PIPE_H_
#define _K3B_ACTIVE_PIPE_H_
-#include <qcstring.h>
+#include <tqcstring.h>
#include <k3b_export.h>
-class QIODevice;
+class TQIODevice;
/**
@@ -74,18 +74,18 @@ class LIBK3B_EXPORT K3bActivePipe
void writeToFd( int fd, bool close = false );
/**
* Read from a QIODevice instead of a file descriptor.
* The device will be opened IO_ReadOnly and closed
* afterwards.
*/
- void readFromIODevice( QIODevice* dev );
+ void readFromIODevice( TQIODevice* dev );
/**
* Write to a QIODevice instead of a file descriptor.
* The device will be opened IO_WriteOnly and closed
* afterwards.
*/
- void writeToIODevice( QIODevice* dev );
+ void writeToIODevice( TQIODevice* dev );
/**
* The file descriptor to write into
@@ -102,12 +102,12 @@ class LIBK3B_EXPORT K3bActivePipe
/**
* The number of bytes that have been read.
*/
- Q_UINT64 bytesRead() const;
+ TQ_UINT64 bytesRead() const;
/**
* The number of bytes that have been written.
*/
- Q_UINT64 bytesWritten() const;
+ TQ_UINT64 bytesWritten() const;
protected:
/**
@@ -74,18 +74,18 @@ class LIBK3B_EXPORT K3bActivePipe
void writeToFd( int fd, bool close = false );
/**
- * Read from a QIODevice instead of a file descriptor.
+ * Read from a TQIODevice instead of a file descriptor.
* The device will be opened IO_ReadOnly and closed
* afterwards.
@@ -74,18 +74,18 @@ class LIBK3B_EXPORT K3bActivePipe
/**
- * Write to a QIODevice instead of a file descriptor.
+ * Write to a TQIODevice instead of a file descriptor.
* The device will be opened IO_WriteOnly and closed
* afterwards.